CREATE 
    TABLE FAQ_ADMINS 
    ( 
        USERNR NUMBER(3,0) NOT NULL, 
        USERNAME VARCHAR2(80) DEFAULT '', 
        PASSWORD VARCHAR2(40) DEFAULT '', 
        EMAIL VARCHAR2(80) DEFAULT '', 
        RIGHTS NUMBER(2,0) DEFAULT 0 NOT NULL, 
        LASTLOGIN NUMBER(10,0) DEFAULT 0 NOT NULL, 
        LOCKPW NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SIGNATURE CLOB DEFAULT '', 
        AUTOPIN NUMBER(10,0) DEFAULT 0 NOT NULL, 
        LANGUAGE VARCHAR2(20) DEFAULT 'en', 
        HIDEEMAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        LOCKENTRY NUMBER(1,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_ADMINS PRIMARY KEY (USERNR) 
    )

CREATE SEQUENCE "FAQ_ADMINS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 21 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_ADMINS" BEFORE 
INSERT 
    ON 
    faq_admins FOR EACH ROW 
    WHEN 
    ( 
        new.usernr IS NULL 
        OR new.usernr = 0 
    ) 
    BEGIN 
SELECT 
    faq_admins_seq.nextval 
INTO 
    :new.usernr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_ADMINS" ENABLE 

CREATE 
    TABLE FAQ_BAD_WORDS 
    ( 
        INDEXNR NUMBER(10,0) NOT NULL, 
        WORD VARCHAR2(100) DEFAULT '', 
        REPLACEMENT VARCHAR2(100) DEFAULT '', 
        CONSTRAINT PK_FAQ_BAD_WORDS PRIMARY KEY (INDEXNR) 
    )

CREATE SEQUENCE "FAQ_BAD_WORDS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_BAD_WORDS" BEFORE 
INSERT 
    ON 
    faq_bad_words FOR EACH ROW 
    WHEN 
    ( 
        new.indexnr IS NULL 
        OR new.indexnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_bad_words_seq.nextval 
INTO 
    :new.indexnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_BAD_WORDS" ENABLE 

CREATE 
    TABLE FAQ_BANLIST 
    ( 
        BANNR NUMBER(10,0) NOT NULL, 
        IPADR VARCHAR2(16) DEFAULT '0.0.0.0', 
        SUBNETMASK VARCHAR2(16) DEFAULT '0.0.0.0', 
        REASON CLOB DEFAULT '', 
        CONSTRAINT PK_FAQ_BANLIST PRIMARY KEY (BANNR) 
    )
    
CREATE SEQUENCE "FAQ_BANLIST_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_BANLIST" BEFORE 
INSERT 
    ON 
    faq_banlist FOR EACH ROW 
    WHEN 
    ( 
        new.bannr IS NULL 
        OR new.bannr = 0 
    ) 
    BEGIN 
SELECT 
    faq_banlist_seq.nextval 
INTO 
    :new.bannr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_BANLIST" ENABLE 
    
CREATE 
    TABLE FAQ_CATEGORY 
    ( 
        CATNR NUMBER(10,0) NOT NULL, 
        CATEGORYNAME VARCHAR2(240) DEFAULT '', 
        NUMFAQS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        PROGRAMM NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_CATEGORY PRIMARY KEY (CATNR) 
    )
    
CREATE SEQUENCE "FAQ_CATEGORY_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_CATEGORY" BEFORE 
INSERT 
    ON 
    faq_category FOR EACH ROW 
    WHEN 
    ( 
        new.catnr IS NULL 
        OR new.catnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_category_seq.nextval 
INTO 
    :new.catnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_CATEGORY" ENABLE 

CREATE 
    TABLE FAQ_CATEGORY_ADMINS 
    ( 
        CATNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        USERNR NUMBER(10,0) DEFAULT 0 NOT NULL 
    )

CREATE 
    TABLE FAQ_CATEGORY_REF 
    ( 
        SRCCATNR NUMBER(10,0) NOT NULL, 
        LANGUAGE VARCHAR2(5) DEFAULT '', 
        DESTCATNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_COMMENTS 
    ( 
        COMMENTNR NUMBER(10,0) NOT NULL, 
        FAQNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        EMAIL VARCHAR2(140) DEFAULT '', 
        COMMENTTEXT CLOB DEFAULT '', 
        IPADR VARCHAR2(16) DEFAULT '0.0.0.0' NOT NULL, 
        POSTDATE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATING NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATINGCOUNT NUMBER(10,0) DEFAULT 0 NOT NULL, 
        VIEWS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_COMMENTS PRIMARY KEY (COMMENTNR) 
    )

CREATE SEQUENCE "FAQ_COMMENTS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_COMMENTS" BEFORE 
INSERT 
    ON 
    faq_comments FOR EACH ROW 
    WHEN 
    ( 
        new.commentnr IS NULL 
        OR new.commentnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_comments_seq.nextval 
INTO 
    :new.commentnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_COMMENTS" ENABLE 

CREATE 
    TABLE FAQ_DATA 
    ( 
        FAQNR NUMBER(10,0) NOT NULL, 
        HEADING VARCHAR2(240) DEFAULT '', 
        CATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        QUESTIONTEXT CLOB DEFAULT '', 
        EDITOR VARCHAR2(80) DEFAULT 'unknown' NOT NULL, 
        EDITDATE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ANSWERTEXT CLOB DEFAULT '', 
        VIEWS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATINGCOUNT NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATING NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        SUBCATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        LINKEDFAQ NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_DATA PRIMARY KEY (FAQNR) 
    )

CREATE SEQUENCE "FAQ_DATA_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_DATA" BEFORE 
INSERT 
    ON 
    faq_data FOR EACH ROW 
    WHEN 
    ( 
        new.faqnr IS NULL 
        OR new.faqnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_data_seq.nextval 
INTO 
    :new.faqnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_DATA" ENABLE 

CREATE 
    TABLE FAQ_DIR_ACCESS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        DIRNAME VARCHAR2(240) DEFAULT '', 
        CONSTRAINT PK_FAQ_DIR_ACCESS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_DIR_ACCESS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_DIR_ACCESS" BEFORE 
INSERT 
    ON 
    faq_dir_access FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_dir_access_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_DIR_ACCESS" ENABLE 

CREATE 
    TABLE FAQ_FAILED_LOGINS 
    ( 
        LOGINNR NUMBER(10,0) NOT NULL, 
        USERNAME VARCHAR2(250) DEFAULT 0 NOT NULL, 
        IPADR VARCHAR2(16) DEFAULT '', 
        LOGINDATE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        USEDPW VARCHAR2(240) DEFAULT '', 
        CONSTRAINT PK_FAQ_FAILED_LOGINS PRIMARY KEY (LOGINNR) 
    )

CREATE SEQUENCE "FAQ_FAILED_LOGINS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_FAILED_LOGINS" BEFORE 
INSERT 
    ON 
    faq_failed_logins FOR EACH ROW 
    WHEN 
    ( 
        new.loginnr IS NULL 
        OR new.loginnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_failed_logins_seq.nextval 
INTO 
    :new.loginnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_FAILED_LOGINS" ENABLE 

CREATE 
    TABLE FAQ_FAILED_NOTIFY 
    ( 
        USERNR NUMBER(10,0) DEFAULT 0 NOT NULL 
    )
    
CREATE 
    TABLE FAQ_FAQ_ATTACHS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        FAQNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ATTACHNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_FAQ_ATTACHS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_FAQ_ATTACHS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_FAQ_ATTACHS" BEFORE 
INSERT 
    ON 
    faq_faq_attachs FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_faq_attachs_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_FAQ_ATTACHS" ENABLE 

CREATE 
    TABLE FAQ_FAQ_KEYWORDS 
    ( 
        FAQNR NUMBER(10,0) NOT NULL, 
        KEYWORDNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_FAQ_OS 
    ( 
        FAQNR NUMBER(10,0) NOT NULL, 
        OSNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_FAQ_PROG_VERSION 
    ( 
        FAQNR NUMBER(10,0) NOT NULL, 
        PROGVERSION NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_FAQ_REF 
    ( 
        SRCFAQNR NUMBER(10,0) NOT NULL, 
        LANGUAGE VARCHAR2(5) DEFAULT '', 
        DESTFAQNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_FILEEXTENSIONS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        MIMETYPE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        EXTENSION VARCHAR2(20) DEFAULT '', 
        CONSTRAINT PK_FAQ_FILEEXTENSIONS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_FILEEXTENSIONS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 61 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_FILEEXTENSIONS" BEFORE 
INSERT 
    ON 
    faq_fileextensions FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_fileextensions_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_FILEEXTENSIONS" ENABLE 

CREATE 
    TABLE FAQ_FILES 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        BINDATA BLOB, 
        FILENAME VARCHAR2(240) DEFAULT '', 
        MIMETYPE VARCHAR2(240) DEFAULT '', 
        FILESIZE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        FS_FILENAME VARCHAR2(240) DEFAULT '', 
        DOWNLOADS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DESCRIPTION VARCHAR2(255) DEFAULT '', 
        CONSTRAINT PK_FAQ_FILES PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_FILES_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE     

CREATE OR REPLACE TRIGGER "T_FAQ_FILES" BEFORE 
INSERT 
    ON 
    faq_files FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_files_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_FILES" ENABLE 

CREATE 
    TABLE FAQ_FILETYPEDESCRIPTION 
    ( 
        MIMETYPE NUMBER(10,0) NOT NULL, 
        LANGUAGE VARCHAR2(10) DEFAULT '', 
        DESCRIPTION VARCHAR2(80) DEFAULT '', 
        CONSTRAINT UQ_FAQ_FILETYPEDESCRIPTION UNIQUE (LANGUAGE, MIMETYPE) 
    )

CREATE 
    TABLE FAQ_FREEMAILER 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        ADDRESS VARCHAR2(100) DEFAULT '', 
        CONSTRAINT PK_FAQ_FREEMAILER PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_FREEMAILER_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_FREEMAILER" BEFORE 
INSERT 
    ON 
    faq_freemailer FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_freemailer_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_FREEMAILER" ENABLE 

CREATE 
    TABLE FAQ_HOSTCACHE 
    ( 
        IPADR VARCHAR2(16) DEFAULT 0 NOT NULL, 
        HOSTNAME VARCHAR2(240) DEFAULT '', 
        CONSTRAINT UQ_FAQ_HOSTCACHE UNIQUE (IPADR) 
    )

CREATE 
    TABLE FAQ_IPLOG 
    ( 
        LOGNR NUMBER(10,0) NOT NULL, 
        USERNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        LOGTIME NUMBER(10,0) DEFAULT 0 NOT NULL, 
        IPADR VARCHAR2(16) DEFAULT '', 
        USED_LANG VARCHAR2(4) DEFAULT '', 
        CONSTRAINT PK_FAQ_IPLOG PRIMARY KEY (LOGNR) 
    )

CREATE SEQUENCE "FAQ_IPLOG_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_IPLOG" BEFORE 
INSERT 
    ON 
    faq_iplog FOR EACH ROW 
    WHEN 
    ( 
        new.lognr IS NULL 
        OR new.lognr = 0 
    ) 
    BEGIN 
SELECT 
    faq_iplog_seq.nextval 
INTO 
    :new.lognr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_IPLOG" ENABLE 

CREATE 
    TABLE FAQ_KB_ARTICLES 
    ( 
        ARTICLENR NUMBER(10,0) NOT NULL, 
        PROGRAMM NUMBER(10,0) DEFAULT 0 NOT NULL, 
        HEADING VARCHAR2(240) DEFAULT '', 
        ARTICLE CLOB DEFAULT '', 
        RATINGCOUNT NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATING NUMBER(10,0) DEFAULT 0 NOT NULL, 
        EDITOR VARCHAR2(80) DEFAULT '', 
        LASTEDITED NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        SUBCATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        VIEWS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_KB_ARTICLES PRIMARY KEY (ARTICLENR) 
    )

CREATE SEQUENCE "FAQ_KB_ARTICLES_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KB_ARTICLES" BEFORE 
INSERT 
    ON 
    faq_kb_articles FOR EACH ROW 
    WHEN 
    ( 
        new.articlenr IS NULL 
        OR new.articlenr = 0 
    ) 
    BEGIN 
SELECT 
    faq_kb_articles_seq.nextval 
INTO 
    :new.articlenr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KB_ARTICLES" ENABLE 

CREATE 
    TABLE FAQ_KB_ATTACHS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        ARTICLENR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ATTACHNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_KB_ATTACHS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_KB_ATTACHS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KB_ATTACHS" BEFORE 
INSERT 
    ON 
    faq_kb_attachs FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_kb_attachs_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KB_ATTACHS" ENABLE 

CREATE 
    TABLE FAQ_KB_CAT 
    ( 
        CATNR NUMBER(10,0) NOT NULL, 
        CATNAME VARCHAR2(240) DEFAULT '', 
        HEADING VARCHAR2(250) DEFAULT '', 
        PROGRAMM NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_KB_CAT PRIMARY KEY (CATNR) 
    )

CREATE SEQUENCE "FAQ_KB_CAT_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KB_CAT" BEFORE 
INSERT 
    ON 
    faq_kb_cat FOR EACH ROW 
    WHEN 
    ( 
        new.catnr IS NULL 
        OR new.catnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_kb_cat_seq.nextval 
INTO 
    :new.catnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KB_CAT" ENABLE 

CREATE 
    TABLE FAQ_KB_KEYWORDS 
    ( 
        ARTICLENR NUMBER(10,0) NOT NULL, 
        KEYWORDNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_KB_OS 
    ( 
        ARTICLENR NUMBER(10,0) NOT NULL, 
        OSNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_KB_PROG_VERSION 
    ( 
        ARTICLENR NUMBER(10,0) NOT NULL, 
        PROGVERSION NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_KB_RATINGS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        RATING NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ARTICLENR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATINGCOMMENT CLOB DEFAULT '', 
        CONSTRAINT PK_FAQ_KB_RATINGS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_KB_RATINGS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KB_RATINGS" BEFORE 
INSERT 
    ON 
    faq_kb_ratings FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_kb_ratings_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KB_RATINGS" ENABLE 

CREATE 
    TABLE FAQ_KB_SUBCAT 
    ( 
        CATNR NUMBER(10,0) NOT NULL, 
        CATNAME VARCHAR2(240) DEFAULT '', 
        HEADING VARCHAR2(250) DEFAULT '', 
        CATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_KB_SUBCAT PRIMARY KEY (CATNR) 
    )

CREATE SEQUENCE "FAQ_KB_SUBCAT_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KB_SUBCAT" BEFORE 
INSERT 
    ON 
    faq_kb_subcat FOR EACH ROW 
    WHEN 
    ( 
        new.catnr IS NULL 
        OR new.catnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_kb_subcat_seq.nextval 
INTO 
    :new.catnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KB_SUBCAT" ENABLE 

CREATE 
    TABLE FAQ_KEYWORDS 
    ( 
        KEYWORDNR NUMBER(10,0) NOT NULL, 
        KEYWORD VARCHAR2(250) DEFAULT '', 
        CONSTRAINT PK_FAQ_KEYWORDS PRIMARY KEY (KEYWORDNR) 
    )

CREATE SEQUENCE "FAQ_KEYWORDS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_KEYWORDS" BEFORE 
INSERT 
    ON 
    faq_keywords FOR EACH ROW 
    WHEN 
    ( 
        new.keywordnr IS NULL 
        OR new.keywordnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_keywords_seq.nextval 
INTO 
    :new.keywordnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_KEYWORDS" ENABLE 

CREATE 
    TABLE FAQ_LAYOUT 
    ( 
        LAYOUTNR NUMBER(3,0) NOT NULL, 
        HEADINGBG VARCHAR2(8) DEFAULT '', 
        BGCOLOR1 VARCHAR2(8) DEFAULT '', 
        BGCOLOR2 VARCHAR2(8) DEFAULT '', 
        PAGEBG VARCHAR2(8) DEFAULT '', 
        TABLEWIDTH VARCHAR2(10) DEFAULT '', 
        FONTFACE VARCHAR2(80) DEFAULT '', 
        FONTSIZE1 VARCHAR2(10) DEFAULT '', 
        FONTSIZE2 VARCHAR2(10) DEFAULT '', 
        FONTSIZE3 VARCHAR2(10) DEFAULT '', 
        FONTCOLOR VARCHAR2(8) DEFAULT '', 
        FONTSIZE4 VARCHAR2(10) DEFAULT '', 
        BGCOLOR3 VARCHAR2(8) DEFAULT '', 
        STYLESHEET VARCHAR2(80) DEFAULT '', 
        HEADINGFONTCOLOR VARCHAR2(8) DEFAULT '', 
        SUBHEADINGFONTCOLOR VARCHAR2(8) DEFAULT '', 
        LINKCOLOR VARCHAR2(8) DEFAULT '', 
        VLINKCOLOR VARCHAR2(8) DEFAULT '', 
        ALINKCOLOR VARCHAR2(8) DEFAULT '', 
        GROUPFONTCOLOR VARCHAR2(8) DEFAULT '', 
        TABLEDESCFONTCOLOR VARCHAR2(8) DEFAULT '', 
        FONTSIZE5 VARCHAR2(10) DEFAULT '', 
        DATEFORMAT VARCHAR2(10) DEFAULT '', 
        NEWTIME NUMBER(4,0) DEFAULT 0 NOT NULL, 
        NEWPIC VARCHAR2(80) DEFAULT '', 
        SEARCHPIC VARCHAR2(80) DEFAULT '', 
        PRINTPIC VARCHAR2(80) DEFAULT '', 
        BACKPIC VARCHAR2(80) DEFAULT '', 
        LISTPIC VARCHAR2(80) DEFAULT '', 
        PAGEHEADER CLOB DEFAULT '', 
        PAGEFOOTER CLOB DEFAULT '', 
        USECUSTOMHEADER NUMBER(1,0) DEFAULT 1 NOT NULL, 
        USECUSTOMFOOTER NUMBER(1,0) DEFAULT 1 NOT NULL, 
        EMAILPIC VARCHAR2(80) DEFAULT '', 
        QUESTIONPIC VARCHAR2(80) DEFAULT '', 
        USERCOMMENTPIC VARCHAR2(80) DEFAULT '', 
        ALLOWLISTS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ALLOWSEARCH NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SEARCHCOMMENTS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SEARCHQUESTIONS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SHOWSUMMARY NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SUMMARYLENGTH NUMBER(2,0) DEFAULT '40' NOT NULL, 
        PROGRESTRICT NUMBER(1,0) DEFAULT 1 NOT NULL, 
        FOOTERFILE VARCHAR2(240) DEFAULT '', 
        HEADERFILE VARCHAR2(240) DEFAULT '', 
        PRINTHEADER NUMBER(1,0) DEFAULT 0 NOT NULL, 
        PRINTFOOTER NUMBER(1,0) DEFAULT 0 NOT NULL, 
        MINCOMMENTLENGTH NUMBER(3,0) DEFAULT 0 NOT NULL, 
        MINQUESTIONLENGTH NUMBER(3,0) DEFAULT 0 NOT NULL, 
        PROGINFOPIC VARCHAR2(80) DEFAULT '', 
        PROGINFOWIDTH NUMBER(4,0) DEFAULT 0 NOT NULL, 
        PROGINFOHEIGHT NUMBER(4,0) DEFAULT 0 NOT NULL, 
        TEXTAREAWIDTH NUMBER(4,0) DEFAULT 0 NOT NULL, 
        TEXTAREAHEIGHT NUMBER(4,0) DEFAULT 0 NOT NULL, 
        PROGINFOLEFT NUMBER(4,0) DEFAULT 0 NOT NULL, 
        PROGINFOTOP NUMBER(4,0) DEFAULT 0 NOT NULL, 
        HELPWINDOWWIDTH NUMBER(4,0) DEFAULT 0 NOT NULL, 
        HELPWINDOWHEIGHT NUMBER(4,0) DEFAULT 0 NOT NULL, 
        HELPWINDOWLEFT NUMBER(4,0) DEFAULT 0 NOT NULL, 
        HELPWINDOWTOP NUMBER(4,0) DEFAULT 0 NOT NULL, 
        HELPPIC VARCHAR2(80) DEFAULT '', 
        CLOSEPIC VARCHAR2(80) DEFAULT '', 
        KBMODE VARCHAR2(20) DEFAULT 'wizard' NOT NULL, 
        DEFSEARCHMETHOD NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ENABLEKEYWORDSEARCH NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ENABLELANGUAGESELECTOR NUMBER(1,0) DEFAULT 0 NOT NULL, 
        FAQSORTMETHOD NUMBER(1,0) DEFAULT 0 NOT NULL, 
        KBSORTMETHOD NUMBER(1,0) DEFAULT 0 NOT NULL, 
        COPYRIGHTPOS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        COPYRIGHTBGCOLOR VARCHAR2(8) DEFAULT '', 
        ASCHEADER CLOB DEFAULT '', 
        SUBHEADINGBGCOLOR VARCHAR2(8) DEFAULT '', 
        ACTIONBGCOLOR VARCHAR2(8) DEFAULT '', 
        HEADERFILEPOS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        FOOTERFILEPOS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NEWINFOBGCOLOR VARCHAR2(8) DEFAULT '', 
        USEASCHEADER NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ASCLINELENGTH NUMBER(4,0) DEFAULT 0 NOT NULL, 
        ASCFORCEWRAP NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ADDBODYTAGS VARCHAR2(240) DEFAULT '', 
        ASCLISTMIMETYPE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ASCLISTCHARSET VARCHAR2(80) DEFAULT 'iso-8859-1', 
        KEYWORDSEARCHMODE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        QUESTIONREQUIREOS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        QUESTIONREQUIREVERSION NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NEWFAQDISPLAYMETHOD NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ENABLEFAQNEWDISPLAY NUMBER(1,0) DEFAULT 0 NOT NULL, 
        FAQNEWDISPLAYBGCOLOR VARCHAR2(8) DEFAULT '', 
        FAQNEWDISPLAYFONTCOLOR VARCHAR2(8) DEFAULT '', 
        LISTALLFAQMETHOD NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ENABLESHORTCUTBAR NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ENABLEJUMPBOXES NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SUBCATBGCOLOR VARCHAR2(8) DEFAULT '', 
        SUBCATFONTCOLOR VARCHAR2(8) DEFAULT '', 
        DISPLAYRELATED NUMBER(1,0) DEFAULT 0 NOT NULL, 
        HTMLLISTTYPE NUMBER(2,0) DEFAULT 0 NOT NULL, 
        PAGETOPPIC VARCHAR2(80) DEFAULT 'gfx/top.gif', 
        ATTACHPIC VARCHAR2(80) DEFAULT 'gfx/attach.gif', 
        SUMMARYINTOTALLIST NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SUMMARYCHARS NUMBER(2,0) DEFAULT 40 NOT NULL, 
        MAXENTRIES NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ACTIVCELLCOLOR VARCHAR2(8) DEFAULT '#ffff72', 
        RATINGSPUBLIC NUMBER(1,0) DEFAULT 0 NOT NULL, 
        RATINGCOMMENTPUBLIC NUMBER(1,0) DEFAULT 0 NOT NULL, 
        HOVERCELLS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        QESAUTOPUB NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NS6STYLE VARCHAR2(240) DEFAULT 'faq_ns6.css', 
        OPERASTYLE VARCHAR2(240) DEFAULT 'faq_opera.css', 
        GECKOSTYLE VARCHAR2(240) DEFAULT 'faq_gecko.css', 
        KONQUERORSTYLE VARCHAR2(240) DEFAULT 'faq_konqueror.css', 
        ASCHEADERFILE VARCHAR2(240) DEFAULT '', 
        ASCHEADERFILEPOS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NUMLATEST NUMBER(4,0) DEFAULT 10 NOT NULL, 
        COLORSCROLLBARS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SBFACECOLOR VARCHAR2(7) DEFAULT '#94AAD6', 
        SBHIGHLIGHTCOLOR VARCHAR2(7) DEFAULT '#AFEEEE', 
        SBSHADOWCOLOR VARCHAR2(7) DEFAULT '#ADD8E6', 
        SB3DLIGHTCOLOR VARCHAR2(7) DEFAULT '#1E90FF', 
        SBARROWCOLOR VARCHAR2(7) DEFAULT '#0000ff', 
        SBTRACKCOLOR VARCHAR2(7) DEFAULT '#E0FFFF', 
        SBDARKSHADOWCOLOR VARCHAR2(7) DEFAULT '#4682B4', 
        PAGEBGPIC VARCHAR2(240) DEFAULT '', 
        TABLEDESCFONTSIZE VARCHAR2(20) DEFAULT '10pt', 
        LANGSELECTFONTSIZE VARCHAR2(20) DEFAULT '10pt', 
        FAQNEWFONTSIZE VARCHAR2(20) DEFAULT '10pt', 
        JUMPBOXFONTSIZE VARCHAR2(20) DEFAULT '10pt', 
        ACTIONLINEFONTSIZE VARCHAR2(20) DEFAULT '9pt', 
        NEWINFOFONTSIZE VARCHAR2(20) DEFAULT '9pt', 
        NEWINFOFONTCOLOR VARCHAR2(7) DEFAULT '#000000', 
        SHORTBARFONTSIZE VARCHAR2(20) DEFAULT '9pt', 
        JUMPBOXSORTING NUMBER(4,0) DEFAULT 0 NOT NULL, 
        DISABLEASCLIST NUMBER(1,0) DEFAULT 0 NOT NULL, 
        DISABLEHTMLEMAIL NUMBER(1,0) DEFAULT 1 NOT NULL, 
        CONTENTCOPY VARCHAR2(250) DEFAULT '', 
        PAGEBGATTACH VARCHAR2(80) DEFAULT 'scroll', 
        PAGEBGREPEAT VARCHAR2(80) DEFAULT 'repeat', 
        PAGEBGPOSITION VARCHAR2(80) DEFAULT 'top', 
        SUBCATFONTSIZE VARCHAR2(10) DEFAULT '12pt', 
        QUESTIONSHORTING NUMBER(10,0) DEFAULT 20 NOT NULL, 
        CC_FONT VARCHAR2(80) DEFAULT '"Times New Roman", Times, serif', 
        CC_FONTSIZE VARCHAR2(20) DEFAULT '12pt', 
        CC_FONTCOLOR VARCHAR2(7) DEFAULT '', 
        SUBSCRIPTIONPIC VARCHAR2(240) DEFAULT 'gfx/subscribe.gif', 
        IROW_BGCOLOR VARCHAR2(7) DEFAULT '#ADD8E6', 
        IROW_FONTCOLOR VARCHAR2(7) DEFAULT '#808100', 
        IROW_FONTSIZE VARCHAR2(20) DEFAULT '12pt', 
        PAGENAVFONTCOLOR VARCHAR2(7) DEFAULT '#000000', 
        PAGENAVFONTSIZE VARCHAR2(20) DEFAULT '9pt', 
        SUBCATFONTSTYLE NUMBER(2,0) DEFAULT 1 NOT NULL, 
        LINKOPTIONS NUMBER(4,0) DEFAULT 0 NOT NULL, 
        LISTOPTIONS NUMBER(4,0) DEFAULT 0 NOT NULL, 
        CLIST_LINKCOLOR VARCHAR2(7) DEFAULT '#000000', 
        CLIST_VLINKCOLOR VARCHAR2(7) DEFAULT '#000000', 
        CLIST_ALINKCOLOR VARCHAR2(7) DEFAULT '#000000', 
        SHOWNEXTPREV NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NEXTPREVMODE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        KBSEARCHOPTIONS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        SEARCHOPTIONS NUMBER(4,0) DEFAULT 0 NOT NULL, 
        DISPLAYOPTIONS NUMBER(4,0) DEFAULT 0 NOT NULL, 
        NEXTPAGEPIC VARCHAR2(80) DEFAULT 'gfx/fwd.gif', 
        PREVPAGEPIC VARCHAR2(80) DEFAULT 'gfx/prev.gif', 
        FIRSTPAGEPIC VARCHAR2(80) DEFAULT 'gfx/first.gif', 
        LASTPAGEPIC VARCHAR2(80) DEFAULT 'gfx/last.gif', 
        USEPAGENAVICONS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        DISPLAYVOTESINLINE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        TABLEALIGN NUMBER(4,0) DEFAULT 2 NOT NULL, 
        VOTESINLINEDISPLAYMODE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NAVBARWIDTH NUMBER(10,0) DEFAULT 250 NOT NULL, 
        NAVSYNC NUMBER(1,0) DEFAULT 1 NOT NULL, 
        NAVPIC_PROGCLOSED VARCHAR2(80) DEFAULT 'gfx/book_closed.gif', 
        NAVPIC_PROGOPEN VARCHAR2(80) DEFAULT 'gfx/book_open.gif', 
        NAVPIC_PROGLOCKED VARCHAR2(80) DEFAULT 'gfx/book_locked.gif', 
        NAVPIC_FAQ VARCHAR2(80) DEFAULT 'gfx/document.gif', 
        NAVPIC_QUESTION VARCHAR2(80) DEFAULT 'gfx/question2.gif', 
        NAVPIC_CATCLOSED VARCHAR2(80) DEFAULT 'gfx/cat_closed.gif', 
        NAVPIC_CATOPEN VARCHAR2(80) DEFAULT 'gfx/cat_open.gif', 
        NAVPIC_CATLOCKED VARCHAR2(80) DEFAULT 'gfx/cat_locked.gif', 
        NAVPIC_SUBCATOPEN VARCHAR2(80) DEFAULT 'gfx/subcat_open.gif', 
        NAVPIC_SUBCATCLOSED VARCHAR2(80) DEFAULT 'gfx/subcat_closed.gif', 
        NAVPIC_SUBCATLOCKED VARCHAR2(80) DEFAULT 'gfx/subcat_locked.gif', 
        SEARCHHIGHLIGHTCOLOR VARCHAR2(7) DEFAULT '#ff0000', 
        SEARCHHIGHLIGHT NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NAVPIC_KBARTICLE VARCHAR2(80) DEFAULT 'gfx/document.gif', 
        NAVPIC_KBWIZARD VARCHAR2(80) DEFAULT 'gfx/wizard.gif', 
        KBNAVOPTIONS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        NAVPIC_KBSEARCH VARCHAR2(80) DEFAULT 'gfx/search.gif', 
        NAVTREEPOS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SEARCH_INPUTFIELDWIDTH NUMBER(4,0) DEFAULT 60 NOT NULL, 
        FAQNAVOPTIONS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ID VARCHAR2(10) DEFAULT '', 
        DEFLAYOUT NUMBER(1,0) DEFAULT 0 NOT NULL, 
        TABLESPACING NUMBER(4,0) DEFAULT 1 NOT NULL, 
        TABLEPADDING NUMBER(4,0) DEFAULT 1 NOT NULL, 
        EXTDATEFORMAT VARCHAR2(20) DEFAULT 'Y-m-d H:i:s', 
        SRCHTOOLPIC VARCHAR2(80) DEFAULT 'gfx/srchtool.gif', 
        DONLTRANS NUMBER(4,0) DEFAULT 0 NOT NULL, 
        DISPLAYATTACHINFO NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SHOWEDITOR NUMBER(1,0) DEFAULT 0 NOT NULL, 
        INPUTFONT VARCHAR2(80) DEFAULT 'Verdana, Geneva, Arial, Helvetica, sans-serif', 
        INPUTFONTSIZE VARCHAR2(10) DEFAULT '10pt', 
        INPUTFONTCOLOR VARCHAR2(8) DEFAULT '#000000', 
        INPUTBGCOLOR VARCHAR2(8) DEFAULT '#eeeeee', 
        INPUTBORDERCOLOR VARCHAR2(8) DEFAULT '#000000', 
        INPUTBORDERSIZE VARCHAR2(20) DEFAULT 'thin', 
        SELBORDERSIZE VARCHAR2(20) DEFAULT '', 
        INPUTNOSTYLES NUMBER(1,0) DEFAULT 0 NOT NULL, 
        INPUTBORDERSTYLE VARCHAR2(20) DEFAULT 'inset', 
        SELBORDERSTYLE VARCHAR2(20) DEFAULT 'inset', 
        BUTTONFONT VARCHAR2(80) DEFAULT 'Verdana, Geneva, Arial, Helvetica, sans-serif', 
        BUTTONFONTSIZE VARCHAR2(10) DEFAULT '10pt', 
        BUTTONFONTCOLOR VARCHAR2(8) DEFAULT '#000000', 
        BUTTONBGCOLOR VARCHAR2(8) DEFAULT '#eeeeee', 
        BUTTONBORDERCOLOR VARCHAR2(8) DEFAULT '#000000', 
        BUTTONBORDERSIZE VARCHAR2(20) DEFAULT 'thin', 
        BUTTONBORDERSTYLE VARCHAR2(20) DEFAULT 'solid', 
        CONSTRAINT PK_FAQ_LAYOUT PRIMARY KEY (LAYOUTNR) 
    )

CREATE SEQUENCE "FAQ_LAYOUT_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 21 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_LAYOUT" BEFORE 
INSERT 
    ON 
    faq_layout FOR EACH ROW 
    WHEN 
    ( 
        new.layoutnr IS NULL 
        OR new.layoutnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_layout_seq.nextval 
INTO 
    :new.layoutnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_LAYOUT" ENABLE 

CREATE 
    TABLE FAQ_LEACHERS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        USERAGENT VARCHAR2(80) DEFAULT '', 
        DESCRIPTION CLOB DEFAULT '', 
        CONSTRAINT PK_FAQ_LEACHERS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_LEACHERS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_LEACHERS" BEFORE 
INSERT 
    ON 
    faq_leachers FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_leachers_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_LEACHERS" ENABLE 

CREATE 
    TABLE FAQ_MIMETYPES 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        MIMETYPE VARCHAR2(240) DEFAULT '', 
        ICON VARCHAR2(240) DEFAULT '', 
        CONSTRAINT PK_FAQ_MIMETYPES PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_MIMETYPES_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 61 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_MIMETYPES" BEFORE 
INSERT 
    ON 
    faq_mimetypes FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_mimetypes_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_MIMETYPES" ENABLE 

CREATE 
    TABLE FAQ_MISC 
    ( 
        SHUTDOWN NUMBER(3,0) DEFAULT 0 NOT NULL, 
        SHUTDOWNTEXT CLOB DEFAULT '' 
    )

CREATE 
    TABLE FAQ_OS 
    ( 
        OSNR NUMBER(10,0) NOT NULL, 
        OSNAME VARCHAR2(180) DEFAULT '', 
        CONSTRAINT PK_FAQ_OS PRIMARY KEY (OSNR) 
    )

CREATE SEQUENCE "FAQ_OS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_OS" BEFORE 
INSERT 
    ON 
    faq_os FOR EACH ROW 
    WHEN 
    ( 
        new.osnr IS NULL 
        OR new.osnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_os_seq.nextval 
INTO 
    :new.osnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_OS" ENABLE 

CREATE 
    TABLE FAQ_PROGRAMM 
    ( 
        PROGNR NUMBER(10,0) NOT NULL, 
        PROGRAMMNAME VARCHAR2(240) DEFAULT '', 
        NUMCATS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        PROGID VARCHAR2(10) DEFAULT '', 
        LANGUAGE VARCHAR2(5) DEFAULT 'de' NOT NULL, 
        NEWSGROUP VARCHAR2(250) DEFAULT '', 
        NEWSSUBJECT VARCHAR2(80) DEFAULT '', 
        NNTPSERVER VARCHAR2(80) DEFAULT '', 
        NEWSDOMAIN VARCHAR2(80) DEFAULT '', 
        DESCRIPTION CLOB DEFAULT '', 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        LASTMAILED NUMBER(10,0) DEFAULT 0 NOT NULL, 
        HTMLMAILTYPE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SUBSCRIPTIONAVAIL NUMBER(1,0) DEFAULT 1 NOT NULL, 
        CONSTRAINT PK_FAQ_PROGRAMM PRIMARY KEY (PROGNR) 
    )

CREATE SEQUENCE "FAQ_PROGRAMM_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_PROGRAMM" BEFORE 
INSERT 
    ON 
    faq_programm FOR EACH ROW 
    WHEN 
    ( 
        new.prognr IS NULL 
        OR new.prognr = 0 
    ) 
    BEGIN 
SELECT 
    faq_programm_seq.nextval 
INTO 
    :new.prognr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_PROGRAMM" ENABLE 

CREATE 
    TABLE FAQ_PROGRAMM_ADMINS 
    ( 
        PROGNR NUMBER(10,0) NOT NULL, 
        USERNR NUMBER(10,0) NOT NULL 
    )
    
CREATE 
    TABLE FAQ_PROGRAMM_VERSION 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        PROGRAMM NUMBER(10,0) DEFAULT 0 NOT NULL, 
        VERSION VARCHAR2(20) DEFAULT '', 
        CONSTRAINT PK_FAQ_PROGRAMM_VERSION PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_PROGRAMM_VERSION_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_PROGRAMM_VERSION" BEFORE 
INSERT 
    ON 
    faq_programm_version FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_programm_version_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_PROGRAMM_VERSION" ENABLE 

CREATE 
    TABLE FAQ_PROG_DIRS 
    ( 
        PROGNR NUMBER(10,0) NOT NULL, 
        DIRNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_PROG_OS 
    ( 
        OSNR NUMBER(10,0) NOT NULL, 
        PROGNR NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_QUESTIONS 
    ( 
        QUESTIONNR NUMBER(10,0) NOT NULL, 
        PROGNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        OSNAME VARCHAR2(180) DEFAULT '', 
        VERSIONNR VARCHAR2(10) DEFAULT '', 
        EMAIL VARCHAR2(140) DEFAULT '', 
        QUESTION CLOB DEFAULT '', 
        ENTERDATE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        FAQREF NUMBER(10,0) DEFAULT 0 NOT NULL, 
        POSTERIP VARCHAR2(20) DEFAULT '', 
        ANSWERDATE NUMBER(20,0) DEFAULT 0 NOT NULL, 
        ANSWERAUTHOR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ANSWER CLOB DEFAULT '', 
        LANGUAGE VARCHAR2(5) DEFAULT 'de' NOT NULL, 
        QUESTIONREF NUMBER(10,0) DEFAULT 0 NOT NULL, 
        PUBLISH NUMBER(1,0) DEFAULT 0 NOT NULL, 
        STATE NUMBER(2,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_QUESTIONS PRIMARY KEY (QUESTIONNR) 
    )

CREATE SEQUENCE "FAQ_QUESTIONS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_QUESTIONS" BEFORE 
INSERT 
    ON 
    faq_questions FOR EACH ROW 
    WHEN 
    ( 
        new.questionnr IS NULL 
        OR new.questionnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_questions_seq.nextval 
INTO 
    :new.questionnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_QUESTIONS" ENABLE 

CREATE 
    TABLE FAQ_RATINGS 
    ( 
        ENTRYNR NUMBER(10,0) NOT NULL, 
        RATING NUMBER(10,0) DEFAULT 0 NOT NULL, 
        FAQNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        RATINGCOMMENT CLOB DEFAULT '', 
        CONSTRAINT PK_FAQ_RATINGS PRIMARY KEY (ENTRYNR) 
    )

CREATE SEQUENCE "FAQ_RATINGS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_RATINGS" BEFORE 
INSERT 
    ON 
    faq_ratings FOR EACH ROW 
    WHEN 
    ( 
        new.entrynr IS NULL 
        OR new.entrynr = 0 
    ) 
    BEGIN 
SELECT 
    faq_ratings_seq.nextval 
INTO 
    :new.entrynr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_RATINGS" ENABLE 

CREATE 
    TABLE FAQ_RELATED_CATEGORIES 
    ( 
        SRCCAT NUMBER(10,0) NOT NULL, 
        DESTCAT NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_RELATED_FAQ 
    ( 
        SRCFAQ NUMBER(10,0) NOT NULL, 
        DESTFAQ NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_RELATED_SUBCAT 
    ( 
        SRCCAT NUMBER(10,0) NOT NULL, 
        DESTCAT NUMBER(10,0) NOT NULL 
    )

CREATE 
    TABLE FAQ_SESSION 
    ( 
        SESSID NUMBER(10,0) NOT NULL, 
        USERNR NUMBER(10,0) NOT NULL, 
        STARTTIME NUMBER(10,0) DEFAULT 0 NOT NULL, 
        REMOTEIP VARCHAR2(15) DEFAULT '', 
        LASTLOGIN NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_SESSION PRIMARY KEY (SESSID) 
    )

CREATE 
    TABLE FAQ_SETTINGS 
    ( 
        SETTINGNR NUMBER(10,0) DEFAULT 0 NOT NULL, 
        SHOWPROGLIST NUMBER(1,0) DEFAULT 0 NOT NULL, 
        WATCHLOGINS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ALLOWEMAIL NUMBER(1,0) DEFAULT 1 NOT NULL, 
        URLAUTOENCODE NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ENABLESPCODE NUMBER(1,0) DEFAULT 1 NOT NULL, 
        NOFREEMAILER NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ALLOWQUESTIONS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        FAQEMAIL VARCHAR2(140) DEFAULT '', 
        ALLOWUSERCOMMENTS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        NEWCOMMENTNOTIFY NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ENABLEFAILEDNOTIFY NUMBER(1,0) DEFAULT 0 NOT NULL, 
        LOGINLIMIT NUMBER(5,0) DEFAULT 0 NOT NULL, 
        TIMEZONE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ENABLEHOSTRESOLVE NUMBER(1,0) DEFAULT 1 NOT NULL, 
        RATECOMMENTS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        USEMENUBAR NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ADMTEXTAREASROWS NUMBER(4,0) DEFAULT 30 NOT NULL, 
        ADMTEXTAREASCOLS NUMBER(4,0) DEFAULT 10 NOT NULL, 
        ENABLEKBRATING NUMBER(1,0) DEFAULT 0 NOT NULL, 
        USERQUESTIONANSWERMODE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        USERQUESTIONANSWERMAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        USERQUESTIONAUTOPUBLISH NUMBER(1,0) DEFAULT 0 NOT NULL, 
        FAQENGINE_HOSTNAME VARCHAR2(140) DEFAULT 'localhost', 
        RATINGCOMMENT NUMBER(1,0) DEFAULT 0 NOT NULL, 
        NOSUNOTIFY NUMBER(1,0) DEFAULT 0 NOT NULL, 
        BLOCKOLDBROWSER NUMBER(1,0) DEFAULT 1 NOT NULL, 
        BBCCOLORBAR NUMBER(1,0) DEFAULT 1 NOT NULL, 
        DISABLEHTMLEMAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ADMSTOREFAQFILTERS NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ADMHIDEUNASSIGNED NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ADMDELCONFIRM NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ZLIBAVAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        MSENDLIMIT NUMBER(10,0) DEFAULT '30' NOT NULL, 
        SUBSCRIPTIONAVAIL NUMBER(1,0) DEFAULT 1 NOT NULL, 
        ADMEDOPTIONS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ALLSENDCOMPRESSED NUMBER(1,0) DEFAULT 0 NOT NULL, 
        UQ_ALLOWNOEMAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        BLOCKLEACHER NUMBER(1,0) DEFAULT 1 NOT NULL, 
        DEFMAILSIG CLOB DEFAULT '', 
        FAQLISTSHORTCUTS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        FAQLIMITRELATED NUMBER(1,0) DEFAULT 0 NOT NULL, 
        DISPLAYRATING NUMBER(1,0) DEFAULT 0 NOT NULL, 
        ADMDATEFORMAT VARCHAR2(20) DEFAULT 'Y-m-d H:i:s', 
        SHOWTIMEZONE NUMBER(1,0) DEFAULT 1 NOT NULL, 
        SHOWCURRTIME NUMBER(1,0) DEFAULT 1 NOT NULL, 
        MAXCONFIRMTIME NUMBER(4,0) DEFAULT 2 NOT NULL, 
        DOSEARCHLOG NUMBER(1,0) DEFAULT 0 NOT NULL, 
        LOGDATEFORMAT VARCHAR2(20) DEFAULT 'Y-m-d H:i:s', 
        UQSCMAIL NUMBER(1,0) DEFAULT 0 NOT NULL, 
        EXTFAILEDLOG NUMBER(1,0) DEFAULT 0 NOT NULL, 
        USEBWLIST NUMBER(1,0) DEFAULT 0 NOT NULL, 
        LHIDE NUMBER(1,0) DEFAULT 0 NOT NULL, 
        SEARCHMODE NUMBER(3,0) DEFAULT 0 NOT NULL, 
        CSQUESTIONS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        CSCOMMENTS NUMBER(1,0) DEFAULT 0 NOT NULL, 
        DBVERSION NUMBER(6,3) DEFAULT 0 NOT NULL, 
        ADMDATEFORMATSHORT VARCHAR2(20) DEFAULT 'Y-m-d', 
        CONSTRAINT PK_FAQ_SETTINGS PRIMARY KEY (SETTINGNR) 
    )

CREATE 
    TABLE FAQ_SUBCATEGORY 
    ( 
        CATNR NUMBER(10,0) NOT NULL, 
        CATEGORYNAME VARCHAR2(240) DEFAULT '', 
        CATEGORY NUMBER(10,0) DEFAULT 0 NOT NULL, 
        DISPLAYPOS NUMBER(10,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_SUBCATEGORY PRIMARY KEY (CATNR) 
    )

CREATE SEQUENCE "FAQ_SUBCATEGORY_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_SUBCATEGORY" BEFORE 
INSERT 
    ON 
    faq_subcategory FOR EACH ROW 
    WHEN 
    ( 
        new.catnr IS NULL 
        OR new.catnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_subcategory_seq.nextval 
INTO 
    :new.catnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_SUBCATEGORY" ENABLE 

CREATE 
    TABLE FAQ_SUBSCRIPTIONS 
    ( 
        SUBSCRIPTIONNR NUMBER(10,0) NOT NULL, 
        EMAIL VARCHAR2(240) DEFAULT '', 
        CONFIRMED NUMBER(1,0) DEFAULT 0 NOT NULL, 
        LANGUAGE VARCHAR2(4) DEFAULT '', 
        SUBSCRIBEID NUMBER(10,0) DEFAULT 0 NOT NULL, 
        UNSUBSCRIBEID NUMBER(10,0) DEFAULT 0 NOT NULL, 
        ENTERDATE NUMBER(10,0) DEFAULT 0 NOT NULL, 
        EMAILTYPE NUMBER(1,0) DEFAULT 1 NOT NULL, 
        PROGID VARCHAR2(10) DEFAULT '', 
        COMPRESSION NUMBER(1,0) DEFAULT 0 NOT NULL, 
        CONSTRAINT PK_FAQ_SUBSCRIPTIONS PRIMARY KEY (SUBSCRIPTIONNR) 
    )


CREATE SEQUENCE "FAQ_SUBSCRIPTIONS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_SUBSCRIPTIONS" BEFORE 
INSERT 
    ON 
    faq_subscriptions FOR EACH ROW 
    WHEN 
    ( 
        new.subscriptionnr IS NULL 
        OR new.subscriptionnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_subscriptions_seq.nextval 
INTO 
    :new.subscriptionnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_SUBSCRIPTIONS" ENABLE 

CREATE 
    TABLE FAQ_TEXTS 
    ( 
        TEXTNR NUMBER(10,0) NOT NULL, 
        TEXTID VARCHAR2(20) DEFAULT '', 
        LANG VARCHAR2(4) DEFAULT '', 
        TEXT CLOB DEFAULT '', 
        CONSTRAINT PK_FAQ_TEXTS PRIMARY KEY (TEXTNR) 
    )

CREATE SEQUENCE "FAQ_TEXTS_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_TEXTS" BEFORE 
INSERT 
    ON 
    faq_texts FOR EACH ROW 
    WHEN 
    ( 
        new.textnr IS NULL 
        OR new.textnr = 0 
    ) 
    BEGIN 
SELECT 
    faq_texts_seq.nextval 
INTO 
    :new.textnr 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_TEXTS" ENABLE 

CREATE 
    INDEX "FAQ_DATA_CATEGORY" 
    ON 
    "FAQ_DATA" 
    (
        "CATEGORY"
    ) 
    PCTFREE 10 INITRANS 2 MAXTRANS 255 STORAGE
    (
        INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT
    ) 


CREATE 
    INDEX "FAQ_SESSION_REMOTEIP" 
    ON 
    "FAQ_SESSION" 
    (
        "REMOTEIP"
    ) 
    PCTFREE 10 INITRANS 2 MAXTRANS 255 STORAGE
    (
        INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT
    ) 


CREATE 
    INDEX "FAQ_SESSION_STARTTIME" 
    ON 
    "FAQ_SESSION" 
    (
        "STARTTIME"
    ) 
    PCTFREE 10 INITRANS 2 MAXTRANS 255 STORAGE
    (
        INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT
    ) 

CREATE 
    TABLE FAQ_VAL
    ( 
        VAL_ID NUMBER(10,0) NOT NULL, 
        VALTXT CHAR(5) DEFAULT '', 
        TIMEID NUMBER(10,0) NOT NULL,
        CONSTRAINT PK_FAQ_VAL PRIMARY KEY (VAL_ID) 
    )

CREATE SEQUENCE "FAQ_VAL_SEQ" MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 21 CACHE 20 NOORDER NOCYCLE 

CREATE OR REPLACE TRIGGER "T_FAQ_VAL" BEFORE 
INSERT 
    ON 
    faq_val FOR EACH ROW 
    WHEN 
    ( 
        new.val_id IS NULL 
        OR new.val_id = 0 
    ) 
    BEGIN 
SELECT 
    faq_val_seq.nextval 
INTO 
    :new.val_id 
FROM 
    dual;
END; 
ALTER TRIGGER "T_FAQ_VAL" ENABLE 
